/*
Toradex AG

IntLib.h
Header file for the free avilible Interrupt Lib

See also our free sample "Interrupts"

Requires:
- CoProcLib.lib

*/


#ifndef __INTLIB_H__
#define __INTLIB_H__


#ifdef __cplusplus
extern "C" {
#endif


#define INT_VER_MAJ     1
#define INT_VER_MIN     1
#define INT_VER_BUILD   0


//Defines for Interrupt Edge Dedect
#define GPIO_EDGE_RISING 1
#define GPIO_EDGE_FALLING 2

//Defines for Inerrupt Level Dedect
#define GPIO_LEVEL_HIGH (GPIO_EDGE_RISING|4)
#define GPIO_LEVEL_LOW (GPIO_EDGE_FALLING|4)

//Win CE 6.0 and 5.0 compatible version of LoadIntChainHandler()
HANDLE LoadIntChainHandlerCompat(LPCWSTR lpFilename, LPCWSTR lpszFunctionName, BYTE bIRQ);

//Win CE 6.0 and 5.0 compatible version of FreeIntChainHandler()
BOOL FreeIntChainHandlerCompat(HANDLE hInstance);

//Win CE 6.0 and 5.0 compatible version of InterruptInitialize()
BOOL InterruptInitializeCompat(DWORD idInt, HANDLE hEvent, LPVOID pvData, DWORD cbData);

//Win CE 6.0 and 5.0 compatible version of InterruptDisable()
void InterruptDisableCompat(DWORD idInt);

//Win CE 6.0 and 5.0 compatible version of Interrupt()
void InterruptDoneCompat(DWORD idInt);

//Win CE 6.0 and 5.0 compatible version of CreateStaticMapping()
LPVOID CreateStaticMappingCompat(DWORD dwPhysBase, DWORD dwSize);

//Win CE 6.0 and 5.0 compatible version of KernelLibIoControl()
BOOL KernelLibIoControlCompat(HANDLE hModule, DWORD dwIoControlCode, LPVOID lpInBuf, DWORD nInBufSize, LPVOID lpOutBuf, DWORD nOutBufSize, LPDWORD lpBytesReturned);

/*
Get an IRQ for an specific GPIO
dwGpio: GPIO Number
return: IRW Number
*/
DWORD GetGPIOIrq(DWORD dwGpio);

//Set GPIO Interrupt Edge dedect. See also the defines
BOOL SetGPIOIrqEdge(DWORD dwGpio, DWORD dwEdge);

/*
Get the SYSIntr Number for the IRQ
(Replace the KernelIOControl: IOCTL_HAL_REQUEST_SYSINTR)
dwIrq: IRQ Number
return: SysInt Number
*/
DWORD RequestSysInterrupt(DWORD dwIrq);

/*
Releases the SysInterrupt
(Replace the KernelIOControl: IOCTL_HAL_RELEASE_SYSINTR)
dwSysIntr: SysInt Number
*/
BOOL ReleaseSysIntr(DWORD dwSysIntr);


/*
Description:      Returns the library Version
Parameter:
Out-Parameter:
- pVerMaj:          Returns the major version number. Set this parameter to NULL if not required.
- pVerMin:          Returns the minor version number. Set this parameter to NULL if not required.
- pBuild:           Returns the build number.         Set this parameter to NULL if not required.
Return Value:		No return value.
*/
void INTGetLibVersion(DWORD *pVerMaj, DWORD *pVerMin, DWORD *pBuild);

#ifdef __cplusplus
}
#endif


#endif
